==> microgue-1.0.1-py3-none-any.whl: microgue/storages/abstract_storage.py <==
import boto3
import logging
import os
import uuid
from pathlib import Path

logger = logging.getLogger("microgue")


class DownloadFailed(Exception):
    pass


class UploadFailed(Exception):
    pass


class DeleteFailed(Exception):
    pass


class AbstractStorage:
    class File:
        def __init__(self, remote_path=None, local_path=None, url=None):
            self.remote_path = remote_path
            self.local_path = local_path
            self.url = url

    storage = None
    bucket_name = ""
    bucket_public_url = ""

    def __init__(self, *args, **kwargs):
        logger.debug(f"########## {self.__class__.__name__} __init__ ##########")
        logger.debug(f"AbstractStorage.storage: {AbstractStorage.storage}")
        if AbstractStorage.storage is None:
            logger.debug("connecting to s3")
            AbstractStorage.storage = boto3.client("s3")
        else:
            logger.debug("using existing connection to s3")

    def upload(self, local_file_path, remote_file_path=None):
        if remote_file_path is None:
            remote_file_path = str(uuid.uuid4()) + "-" + local_file_path.split("/")[-1]

        logger.debug(f"########## {self.__class__.__name__} Upload ##########")
        logger.debug(f"local_file_path: {local_file_path}")
        logger.debug(f"remote_file_path: {remote_file_path}")

        try:
            self.storage.upload_file(local_file_path, self.bucket_name, remote_file_path)
        except Exception as e:
            logger.error(f"########## {self.__class__.__name__} Upload Error")
            logger.error(f"{e.__class__.__name__}: {str(e)}")
            raise UploadFailed(str(e))

        return self.File(
            remote_path=remote_file_path,
            local_path=local_file_path,
            url=self.bucket_public_url + "/" + remote_file_path
        )

    def download(self, remote_file_path, local_file_path=None):
        if local_file_path is None:
            local_file_path = os.getcwd() + "/" + remote_file_path

        # ensure local_file_path directories exist
        Path(os.path.dirname(local_file_path)).mkdir(parents=True, exist_ok=True)

        logger.debug(f"########## {self.__class__.__name__} Download ##########")
        logger.debug(f"remote_file_path: {remote_file_path}")
        logger.debug(f"local_file_path: {local_file_path}")

        try:
            self.storage.download_file(self.bucket_name, remote_file_path, local_file_path)
        except Exception as e:
            logger.error(f"########## {self.__class__.__name__} Download Error")
            logger.error(f"{e.__class__.__name__}: {str(e)}")
            raise DownloadFailed(str(e))

        return self.File(
            remote_path=remote_file_path,
            local_path=local_file_path,
            url=self.bucket_public_url + "/" + remote_file_path
        )

    def delete(self, remote_file_path):
        logger.debug(f"########## {self.__class__.__name__} Delete ##########")
        logger.debug(f"remote_file_path: {remote_file_path}")

        try:
            self.storage.delete_object(Bucket=self.bucket_name, Key=remote_file_path)
        except Exception as e:
            logger.error(f"########## {self.__class__.__name__} Delete Error")
            logger.error(f"{e.__class__.__name__}: {str(e)}")
            raise DeleteFailed(str(e))

        return True

==> microgue-2.0.0-py3-none-any.whl: microgue/storages/abstract_storage.py <==
import boto3
import os
import uuid
from pathlib import Path
from ..loggers.logger import Logger

logger = Logger()


class DownloadFailed(Exception): pass
class UploadFailed(Exception): pass
class DeleteFailed(Exception): pass


class AbstractStorage:
    class File:
        def __init__(self, remote_path=None, local_path=None, url=None):
            self.remote_path = remote_path
            self.local_path = local_path
            self.url = url

    storage = None
    bucket_name = ""
    bucket_public_url = ""

    def __init__(self, *args, **kwargs):
        logger.debug(f"{self.__class__.__name__}.__init__", priority=2)
        logger.debug(f"AbstractStorage.storage: {AbstractStorage.storage}")
        if AbstractStorage.storage is None:
            logger.debug("connecting to s3")
            AbstractStorage.storage = boto3.client("s3")
        else:
            logger.debug("using existing connection to s3")

    def upload(self, local_file_path, remote_file_path=None):
        if remote_file_path is None:
            remote_file_path = str(uuid.uuid4()) + "-" + local_file_path.split("/")[-1]

        logger.debug(f"{self.__class__.__name__}.upload", priority=2)
        logger.debug(f"local_file_path: {local_file_path}")
        logger.debug(f"remote_file_path: {remote_file_path}")

        try:
            self.storage.upload_file(local_file_path, self.bucket_name, remote_file_path)
        except Exception as e:
            logger.error(f"{self.__class__.__name__}.upload - error", priority=3)
            logger.error(f"{e.__class__.__name__}: {str(e)}")
            raise UploadFailed(str(e))

        return self.File(
            remote_path=remote_file_path,
            local_path=local_file_path,
            url=self.bucket_public_url + "/" + remote_file_path
        )

    def download(self, remote_file_path, local_file_path=None):
        if local_file_path is None:
            local_file_path = os.getcwd() + "/" + remote_file_path

        # ensure local_file_path directories exist
        Path(os.path.dirname(local_file_path)).mkdir(parents=True, exist_ok=True)

        logger.debug(f"{self.__class__.__name__}.download", priority=2)
        logger.debug(f"remote_file_path: {remote_file_path}")
        logger.debug(f"local_file_path: {local_file_path}")

        try:
            self.storage.download_file(self.bucket_name, remote_file_path, local_file_path)
        except Exception as e:
            logger.error(f"{self.__class__.__name__}.download - error", priority=3)
            logger.error(f"{e.__class__.__name__}: {str(e)}")
            raise DownloadFailed(str(e))

        return self.File(
            remote_path=remote_file_path,
            local_path=local_file_path,
            url=self.bucket_public_url + "/" + remote_file_path
        )

    def delete(self, remote_file_path):
        logger.debug(f"{self.__class__.__name__}.delete", priority=2)
        logger.debug(f"remote_file_path: {remote_file_path}")

        try:
            self.storage.delete_object(Bucket=self.bucket_name, Key=remote_file_path)
        except Exception as e:
            logger.error(f"{self.__class__.__name__}.delete - error", priority=3)
            logger.error(f"{e.__class__.__name__}: {str(e)}")
            raise DeleteFailed(str(e))

        return True
